@@ -1,14 +1,15 @@
-import re
-import time
-import vpncmd
-from lxml import html
+from omnitools import getpw, parse_credentials_argv
 from .filemanager import ZS_FM, sha3_512hd
-from .utils import getpw, export_credentials, import_credentials, parse_credentials_argv, create_session
+from .utils import csm, create_session
+from lxml import html
+import vpncmd
+import time
+import re
 
 
 class ZS(ZS_FM):
-    def __init__(self, vpncmd_option = None, vpncmd_setup_cmd_option = None, *args, **kwargs):
-        super().__init__(*args, **kwargs)
+    def __init__(self, *, vpncmd_option = None, vpncmd_setup_cmd_option = None, **kwargs):
+        super().__init__(**kwargs)
         if vpncmd_option and vpncmd_setup_cmd_option:
             self.vpncmd = vpncmd.VPNCMD(**(vpncmd_option or {}))
             self.vpncmd.setup_cmd(*(vpncmd_setup_cmd_option or []))
@@ -34,18 +35,18 @@ class ZS(ZS_FM):
         if use_vpn:
             self.connect_vpn(_NICNAME)
         if not credentials:
-            credentials = parse_credentials_argv()
+            credentials = parse_credentials_argv(True)
             if credentials:
-                export_credentials(credentials, overwrite=True)
+                csm.export_credentials(credentials, overwrite=True)
             else:
-                credentials = import_credentials()
+                credentials = csm.import_credentials()
                 if not credentials:
                     credentials = [
                         input("Enter username: "),
                         getpw("Enter password: "),
                     ]
                     print()
-                    export_credentials(credentials)
+                    csm.export_credentials(credentials)
         if self.debug:
             print("logging in")
         self.s.get(self.domain)
