@@ -1,14 +1,14 @@
+from omnitools import dt2yyyymmddhhmmss, IS_WIN32, getch, KEYS, sha3_512hd, getpw
+from .utils import create_session, csm
+from subprocess import call
+from .api import ZS_API
+from lxml import html
+import traceback
+import requests
+import string
+import copy
 import os
 import re
-import copy
-import string
-import requests
-import traceback
-from lxml import html
-from subprocess import call
-from omnitools import dt2yyyymmddhhmmss, IS_WIN32, getch, KEYS, sha3_512hd
-from .utils import getpw, delete_credentials, create_session
-from .api import ZS_API
 
 
 class ZS_FM(ZS_API):
@@ -28,7 +28,7 @@ class ZS_FM(ZS_API):
     show_help: bool = True
     files_cache: dict = {}
 
-    def __init__(self, debug = False):
+    def __init__(self, *, debug = False):
         self.debug = debug
         self.s = create_session()
 
@@ -372,7 +372,7 @@ class ZS_FM(ZS_API):
                     if confirmation.lower() != "yes":
                         message = "Failed to deleted credentials. Reason: Confirmation is not 'yes'.".format(file[-4])
                         continue
-                    delete_credentials()
+                    csm.delete_credentials()
                     message = "Deleted credentials."
                 elif key_pressed == KEYS.CTRL_C:
                     return True
